/**
 * API request helper
 *
 * @author Pierre Hubert
 */

import { ConfigHelper } from "./ConfigHelper";

/**
 * Perform an API request
 *
 * @param uri Target URI on the server
 * @param args Arguments to include in the request
 * @returns The result of the request, in case of success,
 * @throws An exception in case of failure
 */
export async function serverRequest(uri: string, args?: any): Promise<any> {
	const requestArguments = args || {};

	const fd = new FormData();
	for (let arg in requestArguments) {
		if (requestArguments.hasOwnProperty(arg))
			fd.append(arg, requestArguments[arg]);
	}

	// TODO : add access token, once supported

	const result = await (
		await fetch((await ConfigHelper.apiURL()) + uri, {
			method: "POST",
			body: fd,
		})
	).json();

	return result;
}
